==> py312-contourpy-1.3.1_0.darwin_10.ppc.tbz2: opt/local/Library/Frameworks/Python.framework/Versions/3.12/lib/python3.12/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"/usr/local/lib/python3.12/site-packages/",
        python_path=r"/opt/local/Library/Frameworks/Python.framework/Versions/3.12/bin/python3.12",

        # Package versions
        contourpy_version="1.3.1",
        meson_version="1.6.0",
        mesonpy_version="0.17.1",
        pybind11_version="2.13.6",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/opt/local/var/macports/build/_opt_local_var_macports_sources_rsync.macports.org_macports_release_tarballs_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.3.1/.mesonpy-hdo99k5f/lib/contourpy/util",
        source_dir=r"/opt/local/var/macports/build/_opt_local_var_macports_sources_rsync.macports.org_macports_release_tarballs_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.3.1/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/opt/local/var/macports/build/_opt_local_var_macports_sources_rsync.macports.org_macports_release_tarballs_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.3.1/.mesonpy-hdo99k5f/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="gcc",
        compiler_version="14.2.0",
        linker_id="ld64",
        compile_command="/opt/local/bin/g++-mp-14",

        # Host machine
        host_cpu="power macintosh",
        host_cpu_family="ppc",
        host_cpu_endian="big",
        host_cpu_system="darwin",

        # Build machine, same as host machine if not a cross_build
        build_cpu="power macintosh",
        build_cpu_family="ppc",
        build_cpu_endian="big",
        build_cpu_system="darwin",
    )

==> py312-contourpy-1.3.2_0.darwin_10.ppc.tbz2: opt/local/Library/Frameworks/Python.framework/Versions/3.12/lib/python3.12/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"/usr/local/lib/python3.12/site-packages/",
        python_path=r"/opt/local/Library/Frameworks/Python.framework/Versions/3.12/bin/python3.12",

        # Package versions
        contourpy_version="1.3.2",
        meson_version="1.8.0",
        mesonpy_version="0.18.0",
        pybind11_version="2.13.6",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/opt/local/var/macports/build/_opt_local_var_macports_sources_rsync.macports.org_macports_release_tarballs_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.3.2/build/lib/contourpy/util",
        source_dir=r"/opt/local/var/macports/build/_opt_local_var_macports_sources_rsync.macports.org_macports_release_tarballs_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.3.2/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/opt/local/var/macports/build/_opt_local_var_macports_sources_rsync.macports.org_macports_release_tarballs_ports_python_py-contourpy/py312-contourpy/work/contourpy-1.3.2/build/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="gcc",
        compiler_version="14.2.0",
        linker_id="ld64",
        compile_command="/opt/local/bin/g++-mp-14",

        # Host machine
        host_cpu="power macintosh",
        host_cpu_family="ppc",
        host_cpu_endian="big",
        host_cpu_system="darwin",

        # Build machine, same as host machine if not a cross_build
        build_cpu="power macintosh",
        build_cpu_family="ppc",
        build_cpu_endian="big",
        build_cpu_system="darwin",
    )
